Struct below_store::StoreWriter [−][src]
pub struct StoreWriter { /* fields omitted */ }Expand description
The StoreWriter struct maintains state to put more data in the store. It keeps track of the index and data file it’s currently working on so in the common case it can just append data. When it rolls over to a new shard, it will recreate itself.
Implementations
Create a new StoreWriter that writes data to path directory. Data
serialized with format.
If compress is set, dataframes are zstd compressed.
pub fn new_with_timestamp<P: AsRef<Path>>(
path: P,
timestamp: SystemTime,
compress: bool,
format: Format
) -> Result<Self>Store data with corresponding timestamp. Errors may be returned if file operations fail.
Discard all data earlier than timestamp
We do not modify index and data files. We just look for files which can only contain earlier data and remove them.